@@ -11,23 +11,24 @@ from grid2op.Action.PlayableAction import PlayableAction
 
 class PowerlineSetAndDispatchAction(PlayableAction):
     """
-    This type of :class:`PlayableAction` only implements the 
+    This type of :class:`PlayableAction` only implements the
     modifications of the grid with set topological and dispatch actions.
 
     It accepts the key words: "set_line_status" and  "redispatch".
-    Nothing else is supported and any attempt to use something else 
+    Nothing else is supported and any attempt to use something else
     will have no impact.
     """
+
     authorized_keys = {
         "set_line_status",
         # "set_bus",
-        "redispatch"
+        "redispatch",
     }
 
     attr_list_vect = [
         "_set_line_status",
         # "_set_topo_vect",
-        "_redispatch"
+        "_redispatch",
     ]
 
     attr_list_set = set(attr_list_vect)
