@@ -11,22 +11,17 @@ from grid2op.Action.PlayableAction import PlayableAction
 
 class TopologySetAction(PlayableAction):
     """
-    This type of :class:`PlayableAction` implements the modifications 
+    This type of :class:`PlayableAction` implements the modifications
     of the grid with "set" topological actions.
 
     It accepts the key words: "set_line_status" and "set_bus".
-    Nothing else is supported and any attempt to use something else 
+    Nothing else is supported and any attempt to use something else
     will have no impact.
     """
-    authorized_keys = {
-        "set_line_status",
-        "set_bus"
-    }
 
-    attr_list_vect = [
-        "_set_line_status",
-        "_set_topo_vect"
-    ]
+    authorized_keys = {"set_line_status", "set_bus"}
+
+    attr_list_vect = ["_set_line_status", "_set_topo_vect"]
 
     attr_list_set = set(attr_list_vect)
 
