@@ -14,8 +14,12 @@ from grid2op.Exceptions import UnknownEnv
 from grid2op.MakeEnv.UserUtils import list_available_local_env
 from grid2op.MakeEnv.Make import _retrieve_github_content
 
-_LIST_REMOTE_URL = "https://api.github.com/repos/bdonnot/grid2op-datasets/contents/updates.json"
-_LIST_REMOTE_ENV_HASH = "https://api.github.com/repos/bdonnot/grid2op-datasets/contents/env_hashes.json"
+_LIST_REMOTE_URL = (
+    "https://api.github.com/repos/bdonnot/grid2op-datasets/contents/updates.json"
+)
+_LIST_REMOTE_ENV_HASH = (
+    "https://api.github.com/repos/bdonnot/grid2op-datasets/contents/env_hashes.json"
+)
 
 
 def _write_file(path_local_env, new_config, file_name):
@@ -77,7 +81,11 @@ def _update_file(dict_, env_name, file_name):
                 _write_file(mix_dir, new_config, file_name=file_name)
     else:
         _write_file(path_local_env, new_config, file_name=file_name)
-    print("\t Successfully updated file \"{}\" for environment \"{}\"".format(file_name, env_name))
+    print(
+        '\t Successfully updated file "{}" for environment "{}"'.format(
+            file_name, env_name
+        )
+    )
 
 
 def _do_env_need_update(env_name, env_hashes):
@@ -85,7 +93,7 @@ def _do_env_need_update(env_name, env_hashes):
         # no hash for this environment is provided, i don't know, so in doubt i need to update it (old behaviour)
         return True
     else:
-        # i check if "my" hash is different that the remote hash
+        # i check if "my" hash is different from the remote hash
         base_path = grid2op.get_current_local_dir()
         hash_remote_hex = env_hashes[env_name]
         hash_local = _hash_env(os.path.join(base_path, env_name))
@@ -94,9 +102,7 @@ def _do_env_need_update(env_name, env_hashes):
         return res
 
 
-def _update_files(env_name=None,
-                  answer_json=None,
-                  env_hashes=None):
+def _update_files(env_name=None, answer_json=None, env_hashes=None):
     """
     INTERNAL
 
@@ -133,20 +139,32 @@ def _update_files(env_name=None,
                 dict_main = answer_json[env_name]
                 for k, dict_ in dict_main.items():
                     _update_file(dict_, env_name, file_name=k)
+            elif need_update and env_name not in answer_json:
+                print(
+                    f'Environment: "{env_name}" is not up to date, but we did not found any files to update. '
+                    f'IF this environment is officially supported by grid2op (see full list at '
+                    f'https://grid2op.readthedocs.io/en/latest/available_envs.html#description-of-some-environments) '
+                    f'Please write an issue at :\n\t\t'
+                    f'https://github.com/rte-france/Grid2Op/issues/new?assignees=&labels=question&title=Environment%20{env_name}%20is%20not%20up%20to%20date%20but%20I%20cannot%20update%20it.&body=%3c%21%2d%2dDescribe%20shortly%20the%20context%20%2d%2d%3e%0d'
+                )
             else:
                 # environment is up to date
-                print("Environment \"{}\" is up to date".format(env_name))
+                print('Environment "{}" is up to date'.format(env_name))
         else:
-            raise UnknownEnv("Impossible to locate the environment named \"{}\". Have you downlaoded it?"
-                             "".format(env_name))
+            raise UnknownEnv(
+                'Impossible to locate the environment named "{}". Have you downlaoded it?'
+                "".format(env_name)
+            )
 
 
 # TODO make that a method of the environment maybe ?
-def _hash_env(path_local_env,
-              hash_=None,
-              blocksize=64,  # TODO is this correct ?
-              ):
+def _hash_env(
+    path_local_env,
+    hash_=None,
+    blocksize=64,  # TODO is this correct ?
+):
     import hashlib  # lazy import
+
     if hash_ is None:
         # we use this as it is supposedly faster than md5
         # we don't really care about the "secure" part of it (though it's a nice tool to have)
@@ -161,18 +179,32 @@ def _hash_env(path_local_env,
     else:
         # i am hashing a regular environment
         # first i hash the config files
-        for fn_ in ["alerts_info.json",
-                    "config.py",
-                    "difficulty_levels.json",
-                    "grid.json",
-                    "grid_layout.json",
-                    "prods_charac.csv"]:  # list the file we want to hash (we don't hash everything
+        for fn_ in [
+            "alerts_info.json",
+            "config.py",
+            "difficulty_levels.json",
+            "grid.json",
+            "grid_layout.json",
+            "prods_charac.csv",
+            "storage_units_charac.csv",
+            # chronix2grid files, if any
+            "loads_charac.csv",
+            "params.json",
+            "params_load.json",
+            "params_loss.json",
+            "params_opf.json",
+            "params_res.json",
+            "scenario_params.json",
+        ]:  # list the file we want to hash (we don't hash everything
             full_path_file = os.path.join(path_local_env, fn_)
             import re
+
             if os.path.exists(full_path_file):
                 with open(full_path_file, "r", encoding="utf-8") as f:
                     text_ = f.read()
-                    text_ = re.sub("\s|\n|\r", "", text_)  # this is done to ensure a compatibility between platform
+                    text_ = re.sub(
+                        "\s", "", text_
+                    )  # this is done to ensure a compatibility between platform
                     # sometime git replaces the "\r\n" in windows with "\n" on linux / macos and it messes
                     # up the hash
                     hash_.update(text_.encode("utf-8"))
