@@ -82,6 +82,19 @@ class Parameters:
         Whether or not to ignore the attributes `gen_min_uptime` and `gen_min_downtime`. Basically setting this
         parameter to ``True``
 
+    LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION: ``bool``
+        If set to ``True`` (NOT the default) the environment will automatically limit the curtailment / storage actions that otherwise
+        would lead to infeasible state.
+
+        For example the maximum ramp up of generator at a given step is 100 MW / step (
+        ie you can increase the production of these generators of maximum 100 MW at this step) but if you cumul the storage
+        action and the curtailment action, you ask + 110 MW at this step (for example you curtail 100MW of renewables).
+
+        In this example, if param.LIMIT_INFEASIBLE_CURTAILMENT_ACTION is ``False`` (default) this is a game over. If it's ``True``
+        then the curtailment action is limited so that it does not exceed 100 MW.
+
+        Setting it to ``True`` might help the learning of agent using redispatching.
+
     INIT_STORAGE_CAPACITY: ``float``
         Between 0. and 1. Specify, at the beginning of each episode, what is the storage capacity of each storage unit.
         The storage capacity will be expressed as fraction of storage_Emax. For example, if `INIT_STORAGE_CAPACITY` is
@@ -113,6 +126,7 @@ class Parameters:
         Maximum number of calls to `obs.simuate(...)` allowed per episode (reset each "env.simulate(...)"). Defaults to -1 meaning "as much as you want".
 
     """
+
     def __init__(self, parameters_path=None):
         """
         Build an object representing the _parameters of the game.
@@ -140,7 +154,7 @@ class Parameters:
         # this is expressed in relative value of the thermal limits
         # for example setting "HARD_OVERFLOW_THRESHOLD = 2" is equivalent, if a powerline has a thermal limit of
         # 243 A, to disconnect it instantly if it has a powerflow higher than 2 * 243 = 486 A
-        self.HARD_OVERFLOW_THRESHOLD = dt_float(2.)
+        self.HARD_OVERFLOW_THRESHOLD = dt_float(2.0)
 
         # are the powerflow performed by the environment in DC mode (dc powerflow) or AC (ac powerflow)
         self.ENV_DC = False
@@ -161,7 +175,11 @@ class Parameters:
         # allow dispatch on turned off generator (if ``True`` you can actually dispatch a turned on geenrator)
         self.ALLOW_DISPATCH_GEN_SWITCH_OFF = True
 
-        # storage capacity (NOT in pct)
+        # if a curtailment action is "too strong" it will limit it to the "maximum feasible"
+        # not to break the whole system
+        self.LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION = False
+
+        # storage capacity (NOT in pct so 0.5 = 50%)
         self.INIT_STORAGE_CAPACITY = 0.5
 
         # do i take into account the storage loss in the step function
@@ -182,24 +200,37 @@ class Parameters:
                 warn_msg = "Parameters: the file {} is not found. Continuing with default parameters."
                 warnings.warn(warn_msg.format(parameters_path))
 
-
     @staticmethod
     def _isok_txt(arg):
         if isinstance(arg, type(True)):
             return arg
         if isinstance(arg, type("")):
-            arg = arg.strip("\"")
+            arg = arg.strip('"')
         elif isinstance(arg, type(1)):
             arg = "{}".format(arg)
 
         res = False
-        if arg == "True" or arg == "T" or arg == "true" or arg == "t" or str(arg) == "1":
+        if (
+            arg == "True"
+            or arg == "T"
+            or arg == "true"
+            or arg == "t"
+            or str(arg) == "1"
+        ):
             res = True
-        elif arg == "False" or arg == "F" or arg == "false" or arg == "f" or str(arg) == "0":
+        elif (
+            arg == "False"
+            or arg == "F"
+            or arg == "false"
+            or arg == "f"
+            or str(arg) == "0"
+        ):
             res = False
         else:
-            msg = "It's ambiguous where an argument is True or False. " \
-                  "Please only provide \"True\" or \"False\" and not {}"
+            msg = (
+                "It's ambiguous where an argument is True or False. "
+                'Please only provide "True" or "False" and not {}'
+            )
             raise RuntimeError(msg.format(arg))
         return res
 
@@ -215,18 +246,31 @@ class Parameters:
 
         """
         if "NO_OVERFLOW_DISCONNECTION" in dict_:
-            self.NO_OVERFLOW_DISCONNECTION = Parameters._isok_txt(dict_["NO_OVERFLOW_DISCONNECTION"])
+            self.NO_OVERFLOW_DISCONNECTION = Parameters._isok_txt(
+                dict_["NO_OVERFLOW_DISCONNECTION"]
+            )
 
         if "IGNORE_MIN_UP_DOWN_TIME" in dict_:
-            self.IGNORE_MIN_UP_DOWN_TIME = Parameters._isok_txt(dict_["IGNORE_MIN_UP_DOWN_TIME"])
-
+            self.IGNORE_MIN_UP_DOWN_TIME = Parameters._isok_txt(
+                dict_["IGNORE_MIN_UP_DOWN_TIME"]
+            )
         if "ALLOW_DISPATCH_GEN_SWITCH_OFF" in dict_:
-            self.ALLOW_DISPATCH_GEN_SWITCH_OFF = Parameters._isok_txt(dict_["ALLOW_DISPATCH_GEN_SWITCH_OFF"])
+            self.ALLOW_DISPATCH_GEN_SWITCH_OFF = Parameters._isok_txt(
+                dict_["ALLOW_DISPATCH_GEN_SWITCH_OFF"]
+            )
+        if "LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION" in dict_:
+            self.LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION = Parameters._isok_txt(
+                dict_["LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION"]
+            )
 
         if "NB_TIMESTEP_POWERFLOW_ALLOWED" in dict_:
-            self.NB_TIMESTEP_OVERFLOW_ALLOWED = dt_int(dict_["NB_TIMESTEP_POWERFLOW_ALLOWED"])
+            self.NB_TIMESTEP_OVERFLOW_ALLOWED = dt_int(
+                dict_["NB_TIMESTEP_POWERFLOW_ALLOWED"]
+            )
         if "NB_TIMESTEP_OVERFLOW_ALLOWED" in dict_:
-            self.NB_TIMESTEP_OVERFLOW_ALLOWED = dt_int(dict_["NB_TIMESTEP_OVERFLOW_ALLOWED"])
+            self.NB_TIMESTEP_OVERFLOW_ALLOWED = dt_int(
+                dict_["NB_TIMESTEP_OVERFLOW_ALLOWED"]
+            )
 
         if "NB_TIMESTEP_RECONNECTION" in dict_:
             self.NB_TIMESTEP_RECONNECTION = dt_int(dict_["NB_TIMESTEP_RECONNECTION"])
@@ -240,9 +284,11 @@ class Parameters:
         if "FORECAST_DC" in dict_:
             new_val = Parameters._isok_txt(dict_["FORECAST_DC"])
             if new_val != self.FORECAST_DC:
-                warnings.warn("The FORECAST_DC attributes is deprecated. Please change the parameters of the "
-                              "\"forecast\" backend with \"env.change_forecast_parameters(new_param)\" function "
-                              "with \"new_param.ENV_DC=...\" ")
+                warnings.warn(
+                    "The FORECAST_DC attributes is deprecated. Please change the parameters of the "
+                    '"forecast" backend with "env.change_forecast_parameters(new_param)" function '
+                    'with "new_param.ENV_DC=..." '
+                )
             self.FORECAST_DC = new_val
 
         if "MAX_SUB_CHANGED" in dict_:
@@ -253,13 +299,17 @@ class Parameters:
 
         if "NB_TIMESTEP_TOPOLOGY_REMODIF" in dict_:
             # for backward compatibility (in case of old dataset)
-            self.NB_TIMESTEP_COOLDOWN_SUB = dt_int(dict_["NB_TIMESTEP_TOPOLOGY_REMODIF"])
+            self.NB_TIMESTEP_COOLDOWN_SUB = dt_int(
+                dict_["NB_TIMESTEP_TOPOLOGY_REMODIF"]
+            )
         if "NB_TIMESTEP_COOLDOWN_SUB" in dict_:
             self.NB_TIMESTEP_COOLDOWN_SUB = dt_int(dict_["NB_TIMESTEP_COOLDOWN_SUB"])
 
         if "NB_TIMESTEP_LINE_STATUS_REMODIF" in dict_:
             # for backward compatibility (in case of old dataset)
-            self.NB_TIMESTEP_COOLDOWN_LINE = dt_int(dict_["NB_TIMESTEP_LINE_STATUS_REMODIF"])
+            self.NB_TIMESTEP_COOLDOWN_LINE = dt_int(
+                dict_["NB_TIMESTEP_LINE_STATUS_REMODIF"]
+            )
         if "NB_TIMESTEP_COOLDOWN_LINE" in dict_:
             self.NB_TIMESTEP_COOLDOWN_LINE = dt_int(dict_["NB_TIMESTEP_COOLDOWN_LINE"])
 
@@ -267,7 +317,9 @@ class Parameters:
         if "INIT_STORAGE_CAPACITY" in dict_:
             self.INIT_STORAGE_CAPACITY = dt_float(dict_["INIT_STORAGE_CAPACITY"])
         if "ACTIVATE_STORAGE_LOSS" in dict_:
-            self.ACTIVATE_STORAGE_LOSS = Parameters._isok_txt(dict_["ACTIVATE_STORAGE_LOSS"])
+            self.ACTIVATE_STORAGE_LOSS = Parameters._isok_txt(
+                dict_["ACTIVATE_STORAGE_LOSS"]
+            )
 
         # alarm parameters
         if "ALARM_BEST_TIME" in dict_:
@@ -282,14 +334,18 @@ class Parameters:
             self.MAX_SIMULATE_PER_EPISODE = dt_int(dict_["MAX_SIMULATE_PER_EPISODE"])
 
         authorized_keys = set(self.__dict__.keys())
-        authorized_keys = authorized_keys | {'NB_TIMESTEP_POWERFLOW_ALLOWED',
-                                             'NB_TIMESTEP_TOPOLOGY_REMODIF',
-                                             "NB_TIMESTEP_LINE_STATUS_REMODIF"}
+        authorized_keys = authorized_keys | {
+            "NB_TIMESTEP_POWERFLOW_ALLOWED",
+            "NB_TIMESTEP_TOPOLOGY_REMODIF",
+            "NB_TIMESTEP_LINE_STATUS_REMODIF",
+        }
 
         ignored_keys = dict_.keys() - authorized_keys
         if len(ignored_keys):
-            warnings.warn("Parameters: The _parameters \"{}\" used to build the Grid2Op.Parameters "
-                          "class are not recognized and will be ignored.".format(ignored_keys))
+            warnings.warn(
+                'Parameters: The _parameters "{}" used to build the Grid2Op.Parameters '
+                "class are not recognized and will be ignored.".format(ignored_keys)
+            )
 
     def to_dict(self):
         """
@@ -305,6 +361,9 @@ class Parameters:
         res["NO_OVERFLOW_DISCONNECTION"] = bool(self.NO_OVERFLOW_DISCONNECTION)
         res["IGNORE_MIN_UP_DOWN_TIME"] = bool(self.IGNORE_MIN_UP_DOWN_TIME)
         res["ALLOW_DISPATCH_GEN_SWITCH_OFF"] = bool(self.ALLOW_DISPATCH_GEN_SWITCH_OFF)
+        res["LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION"] = bool(
+            self.LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION
+        )
         res["NB_TIMESTEP_OVERFLOW_ALLOWED"] = int(self.NB_TIMESTEP_OVERFLOW_ALLOWED)
         res["NB_TIMESTEP_RECONNECTION"] = int(self.NB_TIMESTEP_RECONNECTION)
         res["HARD_OVERFLOW_THRESHOLD"] = float(self.HARD_OVERFLOW_THRESHOLD)
@@ -336,8 +395,10 @@ class Parameters:
                 dict_ = json.load(f)
             self.init_from_dict(dict_)
         except Exception as exc_:
-            warn_msg = "Could not load from {}\n" \
-                       "Continuing with default parameters. \n\nThe error was \"{}\""
+            warn_msg = (
+                "Could not load from {}\n"
+                'Continuing with default parameters. \n\nThe error was "{}"'
+            )
             warnings.warn(warn_msg.format(json_path, exc_))
 
     def __eq__(self, other):
@@ -379,106 +440,178 @@ class Parameters:
                 raise RuntimeError("NO_OVERFLOW_DISCONNECTION should be a boolean")
             self.NO_OVERFLOW_DISCONNECTION = dt_bool(self.NO_OVERFLOW_DISCONNECTION)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert NO_OVERFLOW_DISCONNECTION to bool with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert NO_OVERFLOW_DISCONNECTION to bool with error \n:"{exc_}"'
+            )
 
         try:
-            self.NB_TIMESTEP_OVERFLOW_ALLOWED = int(self.NB_TIMESTEP_OVERFLOW_ALLOWED)  # to raise if numpy array
-            self.NB_TIMESTEP_OVERFLOW_ALLOWED = dt_int(self.NB_TIMESTEP_OVERFLOW_ALLOWED)
+            self.NB_TIMESTEP_OVERFLOW_ALLOWED = int(
+                self.NB_TIMESTEP_OVERFLOW_ALLOWED
+            )  # to raise if numpy array
+            self.NB_TIMESTEP_OVERFLOW_ALLOWED = dt_int(
+                self.NB_TIMESTEP_OVERFLOW_ALLOWED
+            )
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert NB_TIMESTEP_OVERFLOW_ALLOWED to int with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert NB_TIMESTEP_OVERFLOW_ALLOWED to int with error \n:"{exc_}"'
+            )
 
         if self.NB_TIMESTEP_OVERFLOW_ALLOWED < 0:
-            raise RuntimeError("NB_TIMESTEP_OVERFLOW_ALLOWED < 0., this should be >= 0.")
+            raise RuntimeError(
+                "NB_TIMESTEP_OVERFLOW_ALLOWED < 0., this should be >= 0."
+            )
         try:
-            self.NB_TIMESTEP_RECONNECTION = int(self.NB_TIMESTEP_RECONNECTION)  # to raise if numpy array
+            self.NB_TIMESTEP_RECONNECTION = int(
+                self.NB_TIMESTEP_RECONNECTION
+            )  # to raise if numpy array
             self.NB_TIMESTEP_RECONNECTION = dt_int(self.NB_TIMESTEP_RECONNECTION)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert NB_TIMESTEP_RECONNECTION to int with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert NB_TIMESTEP_RECONNECTION to int with error \n:"{exc_}"'
+            )
         if self.NB_TIMESTEP_RECONNECTION < 0:
             raise RuntimeError("NB_TIMESTEP_RECONNECTION < 0., this should be >= 0.")
         try:
             self.NB_TIMESTEP_COOLDOWN_LINE = int(self.NB_TIMESTEP_COOLDOWN_LINE)
             self.NB_TIMESTEP_COOLDOWN_LINE = dt_int(self.NB_TIMESTEP_COOLDOWN_LINE)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert NB_TIMESTEP_COOLDOWN_LINE to int with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert NB_TIMESTEP_COOLDOWN_LINE to int with error \n:"{exc_}"'
+            )
         if self.NB_TIMESTEP_COOLDOWN_LINE < 0:
             raise RuntimeError("NB_TIMESTEP_COOLDOWN_LINE < 0., this should be >= 0.")
         try:
-            self.NB_TIMESTEP_COOLDOWN_SUB = int(self.NB_TIMESTEP_COOLDOWN_SUB)  # to raise if numpy array
+            self.NB_TIMESTEP_COOLDOWN_SUB = int(
+                self.NB_TIMESTEP_COOLDOWN_SUB
+            )  # to raise if numpy array
             self.NB_TIMESTEP_COOLDOWN_SUB = dt_int(self.NB_TIMESTEP_COOLDOWN_SUB)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert NB_TIMESTEP_COOLDOWN_SUB to int with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert NB_TIMESTEP_COOLDOWN_SUB to int with error \n:"{exc_}"'
+            )
         if self.NB_TIMESTEP_COOLDOWN_SUB < 0:
             raise RuntimeError("NB_TIMESTEP_COOLDOWN_SUB < 0., this should be >= 0.")
         try:
-            self.HARD_OVERFLOW_THRESHOLD = float(self.HARD_OVERFLOW_THRESHOLD)  # to raise if numpy array
+            self.HARD_OVERFLOW_THRESHOLD = float(
+                self.HARD_OVERFLOW_THRESHOLD
+            )  # to raise if numpy array
             self.HARD_OVERFLOW_THRESHOLD = dt_float(self.HARD_OVERFLOW_THRESHOLD)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert HARD_OVERFLOW_THRESHOLD to float with error \n:\"{exc_}\"")
-        if self.HARD_OVERFLOW_THRESHOLD < 1.:
-            raise RuntimeError("HARD_OVERFLOW_THRESHOLD < 1., this should be >= 1. (use env.set_thermal_limit "
-                               "to modify the thermal limit)")
+            raise RuntimeError(
+                f'Impossible to convert HARD_OVERFLOW_THRESHOLD to float with error \n:"{exc_}"'
+            )
+        if self.HARD_OVERFLOW_THRESHOLD < 1.0:
+            raise RuntimeError(
+                "HARD_OVERFLOW_THRESHOLD < 1., this should be >= 1. (use env.set_thermal_limit "
+                "to modify the thermal limit)"
+            )
         try:
             if not isinstance(self.ENV_DC, (bool, dt_bool)):
                 raise RuntimeError("NO_OVERFLOW_DISCONNECTION should be a boolean")
             self.ENV_DC = dt_bool(self.ENV_DC)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert ENV_DC to bool with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert ENV_DC to bool with error \n:"{exc_}"'
+            )
         try:
             self.MAX_SUB_CHANGED = int(self.MAX_SUB_CHANGED)  # to raise if numpy array
             self.MAX_SUB_CHANGED = dt_int(self.MAX_SUB_CHANGED)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert MAX_SUB_CHANGED to int with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert MAX_SUB_CHANGED to int with error \n:"{exc_}"'
+            )
         if self.MAX_SUB_CHANGED < 0:
-            raise RuntimeError("MAX_SUB_CHANGED should be >=0 (or -1 if you want to be able to change every "
-                               "substation at once)")
+            raise RuntimeError(
+                "MAX_SUB_CHANGED should be >=0 (or -1 if you want to be able to change every "
+                "substation at once)"
+            )
         try:
-            self.MAX_LINE_STATUS_CHANGED = int(self.MAX_LINE_STATUS_CHANGED)  # to raise if numpy array
+            self.MAX_LINE_STATUS_CHANGED = int(
+                self.MAX_LINE_STATUS_CHANGED
+            )  # to raise if numpy array
             self.MAX_LINE_STATUS_CHANGED = dt_int(self.MAX_LINE_STATUS_CHANGED)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert MAX_LINE_STATUS_CHANGED to int with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert MAX_LINE_STATUS_CHANGED to int with error \n:"{exc_}"'
+            )
         if self.MAX_LINE_STATUS_CHANGED < 0:
-            raise RuntimeError("MAX_LINE_STATUS_CHANGED should be >=0 "
-                               "(or -1 if you want to be able to change every powerline at once)")
+            raise RuntimeError(
+                "MAX_LINE_STATUS_CHANGED should be >=0 "
+                "(or -1 if you want to be able to change every powerline at once)"
+            )
         try:
             if not isinstance(self.IGNORE_MIN_UP_DOWN_TIME, (bool, dt_bool)):
                 raise RuntimeError("IGNORE_MIN_UP_DOWN_TIME should be a boolean")
             self.IGNORE_MIN_UP_DOWN_TIME = dt_bool(self.IGNORE_MIN_UP_DOWN_TIME)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert IGNORE_MIN_UP_DOWN_TIME to bool with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert IGNORE_MIN_UP_DOWN_TIME to bool with error \n:"{exc_}"'
+            )
         try:
             if not isinstance(self.ALLOW_DISPATCH_GEN_SWITCH_OFF, (bool, dt_bool)):
                 raise RuntimeError("ALLOW_DISPATCH_GEN_SWITCH_OFF should be a boolean")
-            self.ALLOW_DISPATCH_GEN_SWITCH_OFF = dt_bool(self.ALLOW_DISPATCH_GEN_SWITCH_OFF)
+            self.ALLOW_DISPATCH_GEN_SWITCH_OFF = dt_bool(
+                self.ALLOW_DISPATCH_GEN_SWITCH_OFF
+            )
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert ALLOW_DISPATCH_GEN_SWITCH_OFF to bool with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert ALLOW_DISPATCH_GEN_SWITCH_OFF to bool with error \n:"{exc_}"'
+            )
+        try:
+            if not isinstance(
+                self.LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION, (bool, dt_bool)
+            ):
+                raise RuntimeError(
+                    "LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION should be a boolean"
+                )
+            self.LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION = dt_bool(
+                self.LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION
+            )
+        except Exception as exc_:
+            raise RuntimeError(
+                f'Impossible to convert LIMIT_INFEASIBLE_CURTAILMENT_STORAGE_ACTION to bool with error \n:"{exc_}"'
+            )
 
         try:
-            self.INIT_STORAGE_CAPACITY = float(self.INIT_STORAGE_CAPACITY)  # to raise if numpy array
+            self.INIT_STORAGE_CAPACITY = float(
+                self.INIT_STORAGE_CAPACITY
+            )  # to raise if numpy array
             self.INIT_STORAGE_CAPACITY = dt_float(self.INIT_STORAGE_CAPACITY)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert INIT_STORAGE_CAPACITY to float with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert INIT_STORAGE_CAPACITY to float with error \n:"{exc_}"'
+            )
 
-        if self.INIT_STORAGE_CAPACITY < 0.:
-            raise RuntimeError("INIT_STORAGE_CAPACITY < 0., this should be within range [0., 1.]")
-        if self.INIT_STORAGE_CAPACITY > 1.:
-            raise RuntimeError("INIT_STORAGE_CAPACITY > 1., this should be within range [0., 1.]")
+        if self.INIT_STORAGE_CAPACITY < 0.0:
+            raise RuntimeError(
+                "INIT_STORAGE_CAPACITY < 0., this should be within range [0., 1.]"
+            )
+        if self.INIT_STORAGE_CAPACITY > 1.0:
+            raise RuntimeError(
+                "INIT_STORAGE_CAPACITY > 1., this should be within range [0., 1.]"
+            )
 
         try:
             if not isinstance(self.ACTIVATE_STORAGE_LOSS, (bool, dt_bool)):
                 raise RuntimeError("ACTIVATE_STORAGE_LOSS should be a boolean")
             self.ACTIVATE_STORAGE_LOSS = dt_bool(self.ACTIVATE_STORAGE_LOSS)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert ACTIVATE_STORAGE_LOSS to bool with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert ACTIVATE_STORAGE_LOSS to bool with error \n:"{exc_}"'
+            )
 
         try:
             self.ALARM_WINDOW_SIZE = dt_int(self.ALARM_WINDOW_SIZE)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert ALARM_WINDOW_SIZE to int with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert ALARM_WINDOW_SIZE to int with error \n:"{exc_}"'
+            )
         try:
             self.ALARM_BEST_TIME = dt_int(self.ALARM_BEST_TIME)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert ALARM_BEST_TIME to int with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert ALARM_BEST_TIME to int with error \n:"{exc_}"'
+            )
 
         if self.ALARM_WINDOW_SIZE <= 0:
             raise RuntimeError("self.ALARM_WINDOW_SIZE should be a positive integer !")
@@ -486,17 +619,29 @@ class Parameters:
             raise RuntimeError("self.ALARM_BEST_TIME should be a positive integer !")
 
         try:
-            self.MAX_SIMULATE_PER_STEP = int(self.MAX_SIMULATE_PER_STEP)  # to raise if numpy array
+            self.MAX_SIMULATE_PER_STEP = int(
+                self.MAX_SIMULATE_PER_STEP
+            )  # to raise if numpy array
             self.MAX_SIMULATE_PER_STEP = dt_int(self.MAX_SIMULATE_PER_STEP)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert MAX_SIMULATE_PER_STEP to int with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert MAX_SIMULATE_PER_STEP to int with error \n:"{exc_}"'
+            )
         if self.MAX_SIMULATE_PER_STEP <= -2:
-            raise RuntimeError(f"self.MAX_SIMULATE_PER_STEP should be a positive integer or -1, we found {self.MAX_SIMULATE_PER_STEP}")
+            raise RuntimeError(
+                f"self.MAX_SIMULATE_PER_STEP should be a positive integer or -1, we found {self.MAX_SIMULATE_PER_STEP}"
+            )
 
         try:
-            self.MAX_SIMULATE_PER_EPISODE = int(self.MAX_SIMULATE_PER_EPISODE)  # to raise if numpy array
+            self.MAX_SIMULATE_PER_EPISODE = int(
+                self.MAX_SIMULATE_PER_EPISODE
+            )  # to raise if numpy array
             self.MAX_SIMULATE_PER_EPISODE = dt_int(self.MAX_SIMULATE_PER_EPISODE)
         except Exception as exc_:
-            raise RuntimeError(f"Impossible to convert MAX_SIMULATE_PER_EPISODE to int with error \n:\"{exc_}\"")
+            raise RuntimeError(
+                f'Impossible to convert MAX_SIMULATE_PER_EPISODE to int with error \n:"{exc_}"'
+            )
         if self.MAX_SIMULATE_PER_EPISODE <= -2:
-            raise RuntimeError(f"self.MAX_SIMULATE_PER_EPISODE should be a positive integer or -1, we found {self.MAX_SIMULATE_PER_EPISODE}")
+            raise RuntimeError(
+                f"self.MAX_SIMULATE_PER_EPISODE should be a positive integer or -1, we found {self.MAX_SIMULATE_PER_EPISODE}"
+            )
