@@ -36,6 +36,7 @@ class BridgeReward(BaseReward):
         # the reward is computed with this class (computing the penalty based on the number of "bridges" in the grid)
 
     """
+
     def __init__(self, min_pen_lte=0.0, max_pen_gte=1.0):
         BaseReward.__init__(self)
         self.reward_min = dt_float(0.0)
@@ -43,8 +44,7 @@ class BridgeReward(BaseReward):
         self.min_pen_lte = dt_float(min_pen_lte)
         self.max_pen_gte = dt_float(max_pen_gte)
 
-    def __call__(self, action, env, has_error,
-                 is_done, is_illegal, is_ambiguous):
+    def __call__(self, action, env, has_error, is_done, is_illegal, is_ambiguous):
         if has_error or is_illegal or is_ambiguous:
             return self.reward_min
 
@@ -59,11 +59,11 @@ class BridgeReward(BaseReward):
         ex_topo = obs.line_ex_pos_topo_vect
         or_sub = obs.line_or_to_subid
         ex_sub = obs.line_ex_to_subid
-        
+
         # Create a graph of vertices
         # Use one vertex per substation per bus
         G = nx.Graph()
-        
+
         # Set lines edges for current bus
         for line_idx in range(n_line):
             # Skip if line is disconnected
@@ -80,12 +80,12 @@ class BridgeReward(BaseReward):
                 continue
 
             # Compute edge vertices indices for current graph
-            left_v =  lor_sub + (lor_bus - 1) * n_sub
+            left_v = lor_sub + (lor_bus - 1) * n_sub
             right_v = lex_sub + (lex_bus - 1) * n_sub
 
             # Register edge in graph
             G.add_edge(left_v, right_v)
-            
+
         # Find the bridges
         n_bridges = dt_float(len(list(nx.bridges(G))))
 
@@ -93,7 +93,9 @@ class BridgeReward(BaseReward):
         n_bridges = max(n_bridges, self.min_pen_lte)
         # Clip to max penalty
         n_bridges = min(n_bridges, self.max_pen_gte)
-        r = np.interp(n_bridges,
-                      [self.min_pen_lte, self.max_pen_gte],
-                      [self.reward_max, self.reward_min])
+        r = np.interp(
+            n_bridges,
+            [self.min_pen_lte, self.max_pen_gte],
+            [self.reward_max, self.reward_min],
+        )
         return dt_float(r)
