@@ -1,8 +1,17 @@
+
+# Copyright (c) 2019-2020, RTE (https://www.rte-france.com)
+# See AUTHORS.txt
+# This Source Code Form is subject to the terms of the Mozilla Public License, version 2.0.
+# If a copy of the Mozilla Public License, version 2.0 was not distributed with this file,
+# you can obtain one at http://mozilla.org/MPL/2.0/.
+# SPDX-License-Identifier: MPL-2.0
+# This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
+
 """
 Grid2Op
 
 """
-__version__ = '1.6.5'
+__version__ = '1.7.0'
 
 __all__ = [
     "Action",
@@ -31,10 +40,15 @@ __all__ = [
     "get_current_local_dir",
     "change_local_dir",
     "list_available_test_env",
-    "update_env"
-]
+    "update_env",
+    "make"
+,]
 
 from grid2op.MakeEnv import make_old, make, make_from_dataset_path
 from grid2op.MakeEnv import update_env
-from grid2op.MakeEnv import list_available_remote_env, list_available_local_env, get_current_local_dir
+from grid2op.MakeEnv import (
+    list_available_remote_env,
+    list_available_local_env,
+    get_current_local_dir,
+)
 from grid2op.MakeEnv import change_local_dir, list_available_test_env
