@@ -98,6 +98,7 @@ class EpisodeStatistics(object):
     when using the :func:`EpisodeStatistics.compute` function.
 
     """
+
     # TODO NB: name for generator are saved as "prod_p.npz", "prod_v.npz" and "prod_q.npz" and not
     # TODO NB: "gen_p.npz" for backward compatibility.
     SCENARIO_IDS = "scenario_ids.npz"
@@ -115,7 +116,7 @@ class EpisodeStatistics(object):
         self.env = env
         self.path_env = self.env.get_path_env()
         nm_ = self.get_name_dir(name_stats)
-        self.path_save_stats = os.path.join(self.path_env, nm_ )
+        self.path_save_stats = os.path.join(self.path_env, nm_)
         self.li_attributes = self.env.observation_space.attr_list_vect
 
     @staticmethod
@@ -130,13 +131,15 @@ class EpisodeStatistics(object):
     def get_name_file(self, observation_attribute):
         """get the name of the file that is used to save a given attribute names"""
         if observation_attribute not in self.li_attributes:
-            raise RuntimeWarning(f"Unknown observation attribute: \"{observation_attribute}\"")
+            raise RuntimeWarning(
+                f'Unknown observation attribute: "{observation_attribute}"'
+            )
         # backward compatibility
-        if observation_attribute == 'gen_p':
+        if observation_attribute == "gen_p":
             observation_attribute = "prod_p"
-        elif observation_attribute == 'gen_q':
+        elif observation_attribute == "gen_q":
             observation_attribute = "prod_q"
-        elif observation_attribute == 'gen_v':
+        elif observation_attribute == "gen_v":
             observation_attribute = "prod_v"
         return f"obs_{observation_attribute}.npz"
 
@@ -154,7 +157,7 @@ class EpisodeStatistics(object):
         return np.load(path)["data"]
 
     def _clean_observations(self, path_tmp, episode_name):
-        full_path = os.path.join(path_tmp, episode_name, EpisodeData.OBSERVATIONS)
+        full_path = os.path.join(path_tmp, episode_name, EpisodeData.OBSERVATIONS_FILE)
         if not os.path.exists(full_path) or not os.path.isfile(full_path):
             # this is not a proper path for the observation
             return
@@ -162,15 +165,22 @@ class EpisodeStatistics(object):
         # todo the way to load back the saved data need to be done in episode data instead
         all_obs = np.load(full_path)["data"]
         # handle the end of the episode
-        with open(os.path.join(path_tmp, episode_name, EpisodeData.META), "r", encoding="utf-8") as f:
+        with open(
+            os.path.join(path_tmp, episode_name, EpisodeData.META),
+            "r",
+            encoding="utf-8",
+        ) as f:
             metadata_ep = json.load(f)
         nb_ts = int(metadata_ep["nb_timestep_played"]) + 1
         all_obs = all_obs[:nb_ts, :]
         for obs_nm in self.env.observation_space.attr_list_vect:
             beg_, end_, dtype = self.env.observation_space.get_indx_extract(obs_nm)
             all_attr = all_obs[:, beg_:end_].astype(dtype)
-            self._save_numpy(os.path.join(path_tmp, episode_name, self.get_name_file(obs_nm)), all_attr)
-        self._delete_if_exists(path_tmp, episode_name,  EpisodeData.OBSERVATIONS)
+            self._save_numpy(
+                os.path.join(path_tmp, episode_name, self.get_name_file(obs_nm)),
+                all_attr,
+            )
+        self._delete_if_exists(path_tmp, episode_name, EpisodeData.OBSERVATIONS_FILE)
 
     def _gather_all(self, li_episodes, dict_metadata, score_names):
         """gather all the data from all the episodes into large array (for easier access later on)"""
@@ -187,16 +197,20 @@ class EpisodeStatistics(object):
             res = None
             for i, (path_tmp, episode_name) in enumerate(li_episodes):
                 # retrieve the content of the attributes
-                tmp_arr = self._load(os.path.join(path_tmp, episode_name, self.get_name_file(obs_nm)))
+                tmp_arr = self._load(
+                    os.path.join(path_tmp, episode_name, self.get_name_file(obs_nm))
+                )
                 if res is None:
                     res = tmp_arr
                 else:
                     res = np.concatenate((res, tmp_arr))
 
                 if first_attr:
-                    dict_metadata[f"{i}"] = {"path": path_tmp,
-                                             "scenario_name": episode_name,
-                                             "nb_step": int(tmp_arr.shape[0])}
+                    dict_metadata[f"{i}"] = {
+                        "path": path_tmp,
+                        "scenario_name": episode_name,
+                        "nb_step": int(tmp_arr.shape[0]),
+                    }
 
                 # save the ids corresponding to each scenarios (but only once)
                 if first_attr:
@@ -209,11 +223,17 @@ class EpisodeStatistics(object):
                     # handles the scores (same, only once)
                     if score_names:
                         for el in score_names:
-                            tmp_scor = self._load(os.path.join(path_tmp, episode_name, el))
+                            tmp_scor = self._load(
+                                os.path.join(path_tmp, episode_name, el)
+                            )
                             if len(score_names) == 0:
-                                dict_metadata[f"{i}"]["scores"] = float(np.sum(tmp_scor))
+                                dict_metadata[f"{i}"]["scores"] = float(
+                                    np.sum(tmp_scor)
+                                )
                             else:
-                                dict_metadata[f"{i}"][f"scores_{el}"] = float(np.sum(tmp_scor))
+                                dict_metadata[f"{i}"][f"scores_{el}"] = float(
+                                    np.sum(tmp_scor)
+                                )
 
                             if scores[el] is None:
                                 scores[el] = tmp_scor
@@ -222,17 +242,25 @@ class EpisodeStatistics(object):
 
             # save for each attributes its content
             path_total = li_episodes[0][0]
-            self._save_numpy(os.path.join(path_total, self.get_name_file(obs_nm)), array=res)
+            self._save_numpy(
+                os.path.join(path_total, self.get_name_file(obs_nm)), array=res
+            )
 
             # save the id, the metadata and the scores but only once
             if first_attr:
-                self._save_numpy(os.path.join(path_total, self.SCENARIO_IDS), array=ids_)
+                self._save_numpy(
+                    os.path.join(path_total, self.SCENARIO_IDS), array=ids_
+                )
                 if score_names:
                     for el in scores:
                         self._save_numpy(os.path.join(path_total, el), array=scores[el])
                     del scores
                 del ids_
-                with open(os.path.join(path_total, EpisodeStatistics.METADATA), "w", encoding="utf-8") as f:
+                with open(
+                    os.path.join(path_total, EpisodeStatistics.METADATA),
+                    "w",
+                    encoding="utf-8",
+                ) as f:
                     json.dump(obj=dict_metadata, fp=f)
             first_attr = False
 
@@ -242,26 +270,36 @@ class EpisodeStatistics(object):
         res = []
         path_env = env.get_path_env()
         for el in os.listdir(path_env):
-            if os.path.exists(os.path.join(path_env, el, EpisodeStatistics.STATISTICS_FOOTPRINT)):
+            if os.path.exists(
+                os.path.join(path_env, el, EpisodeStatistics.STATISTICS_FOOTPRINT)
+            ):
                 res.append((path_env, el))
         return sorted(res)
 
     @staticmethod
     def _nm_score_from_attr_name(attribute_name):
-        return re.sub(f"(_{{0,1}}{EpisodeStatistics.SCORES_CLEAN})|(\\.npz)|(\\.npy)",
-                                 "",
-                                 attribute_name)
+        return re.sub(
+            f"(_{{0,1}}{EpisodeStatistics.SCORES_CLEAN})|(\\.npz)|(\\.npy)",
+            "",
+            attribute_name,
+        )
 
     @staticmethod
     def _is_score_attribute(attribute_name):
         nm = None
         # test if it a single stat or not
-        has_stat = attribute_name == EpisodeStatistics.SCORES or attribute_name == EpisodeStatistics.SCORES_CLEAN
+        has_stat = (
+            attribute_name == EpisodeStatistics.SCORES
+            or attribute_name == EpisodeStatistics.SCORES_CLEAN
+        )
         if has_stat:
             nm = EpisodeStatistics.SCORES
         else:
             # i test if it's a statistics with multiple scores
-            if re.match(f".*_{EpisodeStatistics.SCORES_CLEAN}", attribute_name) is not None:
+            if (
+                re.match(f".*_{EpisodeStatistics.SCORES_CLEAN}", attribute_name)
+                is not None
+            ):
                 # it's a match: multiple score were computed for this name
                 # i need to compute the name with which the files are stored
                 nm_stat = EpisodeStatistics._nm_score_from_attr_name(attribute_name)
@@ -301,27 +339,39 @@ class EpisodeStatistics(object):
         elif attribute_name == "prod_v":
             attribute_name = "gen_v"
 
-        if not os.path.exists(self.path_save_stats) or not os.path.isdir(self.path_save_stats):
-            raise RuntimeError("No statistics were computed for this environment. "
-                               "Please use \"self.compute()\" to compute them. "
-                               "And most importantly have a look at the documentation for precisions about this "
-                               "feature.")
-        ids = self._load(os.path.join(self.path_save_stats, EpisodeStatistics.SCENARIO_IDS)).astype(int)
+        if not os.path.exists(self.path_save_stats) or not os.path.isdir(
+            self.path_save_stats
+        ):
+            raise RuntimeError(
+                "No statistics were computed for this environment. "
+                'Please use "self.compute()" to compute them. '
+                "And most importantly have a look at the documentation for precisions about this "
+                "feature."
+            )
+        ids = self._load(
+            os.path.join(self.path_save_stats, EpisodeStatistics.SCENARIO_IDS)
+        ).astype(int)
         is_score, score_name = EpisodeStatistics._is_score_attribute(attribute_name)
         if is_score:
             if not self._get_has_score():
                 # not score have been saved
-                raise RuntimeError("No score have been computed for this statistics. Please re run \"stats.compute\" "
-                                   "by setting the \"scores_func\" argument.")
+                raise RuntimeError(
+                    'No score have been computed for this statistics. Please re run "stats.compute" '
+                    'by setting the "scores_func" argument.'
+                )
             # TODO here for multiple score
             path_th = os.path.join(self.path_save_stats, score_name)
-            ids_ = np.concatenate((ids[:, 0], (-1, )))
+            ids_ = np.concatenate((ids[:, 0], (-1,)))
             diff_ = np.diff(ids_)
             ids = ids[diff_ == 0, :]
         else:
-            path_th = os.path.join(self.path_save_stats, self.get_name_file(attribute_name))
+            path_th = os.path.join(
+                self.path_save_stats, self.get_name_file(attribute_name)
+            )
         if not os.path.exists(path_th) or not os.path.isfile(path_th):
-            raise RuntimeError(f"Impossible to read the statistics for attribute \"{attribute_name}\"")
+            raise RuntimeError(
+                f'Impossible to read the statistics for attribute "{attribute_name}"'
+            )
         array_ = self._load(path_th)
         return array_, ids
 
@@ -341,10 +391,14 @@ class EpisodeStatistics(object):
         It clears all directory into the "statistics" directory
 
         """
-        if not os.path.exists(self.path_save_stats) or not os.path.isdir(self.path_save_stats):
-            raise RuntimeError("No statistics have been saved for this environment. Please use "
-                               "\"stat.compute\" to save some (this might take a while, "
-                               "see the documentation)")
+        if not os.path.exists(self.path_save_stats) or not os.path.isdir(
+            self.path_save_stats
+        ):
+            raise RuntimeError(
+                "No statistics have been saved for this environment. Please use "
+                '"stat.compute" to save some (this might take a while, '
+                "see the documentation)"
+            )
         for episode_name in sorted(os.listdir(self.path_save_stats)):
             path_tmp = os.path.join(self.path_save_stats, episode_name)
             if os.path.isdir(path_tmp):
@@ -385,23 +439,33 @@ class EpisodeStatistics(object):
 
     def _tell_is_stats(self):
         """put the footprint to inform grid2op this is a stat directory"""
-        path_tmp = os.path.join(self.path_save_stats, EpisodeStatistics.STATISTICS_FOOTPRINT)
+        path_tmp = os.path.join(
+            self.path_save_stats, EpisodeStatistics.STATISTICS_FOOTPRINT
+        )
         with open(path_tmp, "w", encoding="utf-8") as f:
-            f.write("This files is internal to grid2op. Expect some inconsistent behaviour if you attempt to modify "
-                    "it, remove it, alter it in any ways, copy it in another directory etc.\n")
+            f.write(
+                "This files is internal to grid2op. Expect some inconsistent behaviour if you attempt to modify "
+                "it, remove it, alter it in any ways, copy it in another directory etc.\n"
+            )
 
     def _tell_has_score(self):
         """put the footprint to inform grid2op this is a stat directory"""
         path_tmp = os.path.join(self.path_save_stats, EpisodeStatistics.SCORE_FOOTPRINT)
         with open(path_tmp, "w", encoding="utf-8") as f:
-            f.write("This files is internal to grid2op. Expect some inconsistent behaviour if you attempt to modify "
-                    "it, remove it, alter it in any ways, copy it in another directory etc.\n")
+            f.write(
+                "This files is internal to grid2op. Expect some inconsistent behaviour if you attempt to modify "
+                "it, remove it, alter it in any ways, copy it in another directory etc.\n"
+            )
 
     def _get_has_score(self):
         """say if a score has been computed or not"""
-        res = os.path.exists(os.path.join(self.path_save_stats, EpisodeStatistics.SCORE_FOOTPRINT))
+        res = os.path.exists(
+            os.path.join(self.path_save_stats, EpisodeStatistics.SCORE_FOOTPRINT)
+        )
         if res:
-            res = os.path.isfile(os.path.join(self.path_save_stats, EpisodeStatistics.SCORE_FOOTPRINT))
+            res = os.path.isfile(
+                os.path.join(self.path_save_stats, EpisodeStatistics.SCORE_FOOTPRINT)
+            )
         return res
 
     def _fill_metadata(self, agent, parameters, max_step, agent_seeds, env_seeds):
@@ -442,19 +506,38 @@ class EpisodeStatistics(object):
                     continue
                 nm_score = re.sub(f"{self.KEY_SCORE }_", "", possible_key)
                 arr_ = np.array([dt_float(el[possible_key]) for el in dict_rewards])
-                self._save_numpy(os.path.join(path_tmp, episode_name, f"{nm_score}_{self.SCORES}"), arr_)
+                self._save_numpy(
+                    os.path.join(path_tmp, episode_name, f"{nm_score}_{self.SCORES}"),
+                    arr_,
+                )
 
     @staticmethod
     def _check_if_base_reward(stuff):
         return isinstance(stuff, type) and issubclass(stuff, BaseReward)
 
     @staticmethod
-    def run_env(env, path_save, parameters, scores_func, agent, nb_scenario,
-                max_step, env_seeds, agent_seeds, pbar, nb_process):
+    def run_env(
+        env,
+        path_save,
+        parameters,
+        scores_func,
+        agent,
+        nb_scenario,
+        max_step,
+        env_seeds,
+        agent_seeds,
+        pbar,
+        nb_process,
+    ):
 
         if scores_func is not None:
-            if not (EpisodeStatistics._check_if_base_reward(scores_func) or isinstance(scores_func, dict)):
-                raise Grid2OpException("score_func should be either a dictionary or an instance of BaseReward")
+            if not (
+                EpisodeStatistics._check_if_base_reward(scores_func)
+                or isinstance(scores_func, dict)
+            ):
+                raise Grid2OpException(
+                    "score_func should be either a dictionary or an instance of BaseReward"
+                )
 
         dict_kwg = env.get_params_for_runner()
         dict_kwg["parameters_path"] = parameters.to_dict()
@@ -465,35 +548,45 @@ class EpisodeStatistics(object):
                 dict_kwg["other_rewards"][EpisodeStatistics.KEY_SCORE] = scores_func
             elif isinstance(scores_func, dict):
                 for nm, score_fun in scores_func.items():
-                    dict_kwg["other_rewards"][f"{EpisodeStatistics.KEY_SCORE}_{nm}"] = score_fun
+                    dict_kwg["other_rewards"][
+                        f"{EpisodeStatistics.KEY_SCORE}_{nm}"
+                    ] = score_fun
             else:
-                raise RuntimeError("\"scores_func\" should inherit from \"grid2op.Reward.BaseReward\" or "
-                                   "be a dictionary")
+                raise RuntimeError(
+                    '"scores_func" should inherit from "grid2op.Reward.BaseReward" or '
+                    "be a dictionary"
+                )
         runner = Runner(**dict_kwg, agentClass=None, agentInstance=agent)
-        runner.run(path_save=path_save,
-                   nb_episode=nb_scenario,
-                   max_iter=max_step,
-                   env_seeds=env_seeds,
-                   agent_seeds=agent_seeds,
-                   pbar=pbar,
-                   nb_process=nb_process)
+        runner.run(
+            path_save=path_save,
+            nb_episode=nb_scenario,
+            max_iter=max_step,
+            env_seeds=env_seeds,
+            agent_seeds=agent_seeds,
+            pbar=pbar,
+            nb_process=nb_process,
+        )
 
     def get_metadata(self):
         """return the metadata as a dictionary"""
-        with open(os.path.join(self.path_save_stats, self.METADATA), "r", encoding="utf-8") as f:
+        with open(
+            os.path.join(self.path_save_stats, self.METADATA), "r", encoding="utf-8"
+        ) as f:
             res = json.load(f)
         return res
 
-    def compute(self,
-                agent=None,
-                parameters=None,
-                nb_scenario=1,
-                scores_func=None,
-                max_step=-1,
-                env_seeds=None,
-                agent_seeds=None,
-                nb_process=1,
-                pbar=False):
+    def compute(
+        self,
+        agent=None,
+        parameters=None,
+        nb_scenario=1,
+        scores_func=None,
+        max_step=-1,
+        env_seeds=None,
+        agent_seeds=None,
+        nb_process=1,
+        pbar=False,
+    ):
         """
         This function will save (to be later used with :func:`EpisodeStatistics.get_statistics`) all the observation
         at all time steps, for a given number of scenario (see attributes nb_scenario).
@@ -552,14 +645,20 @@ class EpisodeStatistics(object):
         if parameters is None:
             parameters = copy.deepcopy(self.env.parameters)
         if not isinstance(agent, BaseAgent):
-            raise RuntimeError("\"agent\" should be either \"None\" to use DoNothingAgent or an agent that inherits "
-                               "grid2op.Agent.BaseAgent")
+            raise RuntimeError(
+                '"agent" should be either "None" to use DoNothingAgent or an agent that inherits '
+                "grid2op.Agent.BaseAgent"
+            )
         if not isinstance(parameters, Parameters):
-            raise RuntimeError("\"parameters\" should be either \"None\" to use the default parameters passed in the "
-                               "environment or inherits grid2op.Parameters.Parameters")
+            raise RuntimeError(
+                '"parameters" should be either "None" to use the default parameters passed in the '
+                "environment or inherits grid2op.Parameters.Parameters"
+            )
 
         score_names = None
-        dict_metadata = self._fill_metadata(agent, parameters, max_step, agent_seeds, env_seeds)
+        dict_metadata = self._fill_metadata(
+            agent, parameters, max_step, agent_seeds, env_seeds
+        )
 
         if scores_func is not None:
             if EpisodeStatistics._check_if_base_reward(scores_func):
@@ -569,24 +668,30 @@ class EpisodeStatistics(object):
                 score_names = []
                 for nm, score_fun in scores_func.items():
                     if not EpisodeStatistics._check_if_base_reward(score_fun):
-                        raise Grid2OpException("if using \"score_fun\" as a dictionary, each value need to be a "
-                                               "BaseReward")
+                        raise Grid2OpException(
+                            'if using "score_fun" as a dictionary, each value need to be a '
+                            "BaseReward"
+                        )
                     dict_metadata[f"score_class_{nm}"] = f"{score_fun}"
                     score_names.append(f"{nm}_{self.SCORES}")
             else:
-                raise Grid2OpException("score_func should be either a dictionary or an instance of BaseReward")
+                raise Grid2OpException(
+                    "score_func should be either a dictionary or an instance of BaseReward"
+                )
 
-        self.run_env(env=self.env,
-                     path_save=self.path_save_stats,
-                     parameters=parameters,
-                     scores_func=scores_func,
-                     agent=agent,
-                     max_step=max_step,
-                     env_seeds=env_seeds,
-                     agent_seeds=agent_seeds,
-                     pbar=pbar,
-                     nb_process=nb_process,
-                     nb_scenario=nb_scenario)
+        self.run_env(
+            env=self.env,
+            path_save=self.path_save_stats,
+            parameters=parameters,
+            scores_func=scores_func,
+            agent=agent,
+            max_step=max_step,
+            env_seeds=env_seeds,
+            agent_seeds=agent_seeds,
+            pbar=pbar,
+            nb_process=nb_process,
+            nb_scenario=nb_scenario,
+        )
 
         # inform grid2op this is a statistics directory
         self._tell_is_stats()
@@ -602,15 +707,17 @@ class EpisodeStatistics(object):
         li_episodes = EpisodeData.list_episode(self.path_save_stats)
         for path_tmp, episode_name in li_episodes:
             # remove the useless information (saved but not used)
-            self._delete_if_exists(path_tmp, episode_name, EpisodeData.ACTIONS)
+            self._delete_if_exists(path_tmp, episode_name, EpisodeData.ACTIONS_FILE)
             self._delete_if_exists(path_tmp, episode_name, EpisodeData.AG_EXEC_TIMES)
             self._delete_if_exists(path_tmp, episode_name, EpisodeData.LINES_FAILURES)
-            self._delete_if_exists(path_tmp, episode_name, EpisodeData.ENV_ACTIONS)
+            self._delete_if_exists(path_tmp, episode_name, EpisodeData.ENV_ACTIONS_FILE)
             self._delete_if_exists(path_tmp, episode_name, EpisodeData.ATTACK)
             if scores_func is not None:
                 self._retrieve_scores(path_tmp, episode_name)
             else:
-                self._delete_if_exists(path_tmp, episode_name, EpisodeData.OTHER_REWARDS)
+                self._delete_if_exists(
+                    path_tmp, episode_name, EpisodeData.OTHER_REWARDS
+                )
             self._delete_if_exists(path_tmp, episode_name, EpisodeData.REWARDS)
 
             # reformat the observation into a proper "human readable" format
@@ -625,6 +732,7 @@ if __name__ == "__main__":
     from lightsim2grid import LightSimBackend
     from grid2op.Agent import RandomAgent
     from grid2op.Reward import L2RPNSandBoxScore, AlarmReward
+
     # env = grid2op.make("l2rpn_case14_sandbox", backend=LightSimBackend())
     nb_scenario = 2
 
@@ -660,16 +768,23 @@ if __name__ == "__main__":
     # rho_custom_agent, ids = stats_custom_agent.get("rho")
 
     # with multiple "scores"
-    env = grid2op.make("/home/benjamin/Documents/grid2op_dev/grid2op/data_test/l2rpn_neurips_2020_track1_with_alert",
-                       backend=LightSimBackend())
+    env = grid2op.make(
+        "/home/benjamin/Documents/grid2op_dev/grid2op/data_test/l2rpn_neurips_2020_track1_with_alert",
+        backend=LightSimBackend(),
+    )
     stats_dn = EpisodeStatistics(env, name_stats="do_nothing")
-    stats_dn.compute(nb_scenario=nb_scenario,
-                     pbar=True,
-                     scores_func={"grid_operational_cost": L2RPNSandBoxScore,
-                                  "operator_attention": AlarmReward})
+    stats_dn.compute(
+        nb_scenario=nb_scenario,
+        pbar=True,
+        scores_func={
+            "grid_operational_cost": L2RPNSandBoxScore,
+            "operator_attention": AlarmReward,
+        },
+    )
     # rho_dn, ids = stats_dn.get("rho")
     score_op_cost, ids = stats_dn.get("grid_operational_cost_scores")
     score_att_cost, ids = stats_dn.get("operator_attention_scores")
     import pdb
+
     pdb.set_trace()
     assert score_att_cost.shape[0] == ids.shape[0]
